เรียน สร้าง Python Library กับ UncleEngineer”
=============================================

PyPi: https://pypi.org/project/gokuzen/

สวัสดีจ้า gokusen คืออะไร สามารถตรวจสอบข้อมูลว่า gokusen คืออะไร ###
วิธีติดตั้ง

เปิด CMD / Terminal

.. code:: python

   pip install gokuzen

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   from gokuzen import gokuzen

   gokuzen = gokuzen() 
   gokuzen.show_name() #เราชื่ออะไร
   gokuzen.show_mail() #email ของเรา
   gokuzen.about() #gokuzen คืออะไร
   gokuzen.show_ascii() #ภาพศิลปะ

พัฒนาโดย: Gokuzen
